@@ -1,7 +1,8 @@
 #' Function ADI
 #' 
-#' A package to calculate Dominance Indices, print Soical Network Graphs and Music Notation Graphs.
+#' Calculates Average  Dominance Index.
 #' @name ADI
+#' @description Calculates Average  Dominance Index.
 #' @param  data_sheet	 \bold{either} a data.frame f.e imported from a data sheet containing\cr  
 #' "Name","item.number"\cr
 #' "action.from.","action.to","kind.of.action"\cr
@@ -10,7 +11,7 @@
 #' \bold{or} only "action.from.","action.to","kind.of.action"if exists actions and items\cr
 #' \cr
 #' actions: with  "name.of.action","action.number","classification","weighting\cr 
-#' Weigting the factor which should be used to calculate the behavior (1 for "action.from"" wins -1 for "action.to" wins")\cr
+#' weighting the factor which should be used to calculate the behavior (1 for "action.from"" wins -1 for "action.to" wins")\cr
 #' Setting a behaviour to 2 means it is count double\cr
 #' items:  with "Name","item.number"\cr 
 #' @param  bytes	 a string where each enabled action is set to 1 and each disabled action is set to 0\cr
@@ -18,14 +19,9 @@
 #' @param \dots Additional parameters:
 #'  \describe{
 #'   \item{\bold{actions}}{(data.frame) with "name.of.action","action.number","classification","weighting"; Classification 1 if "action.from"" wins; Classification 2 if "action.to" wins}
-#'   \item{\bold{Weigting}}{the factor which should be used to calculate the behavior (1 for "action.from"" wins -1 for "action.to" wins")\cr
+#'   \item{\bold{weighting}}{the factor which should be used to calculate the behavior (1 for "action.from"" wins -1 for "action.to" wins")\cr
 #' Setting a behaviour to 2 means it is count double}
 #'   \item{\bold{vcolors}}{as much colors as items, colors will returned as sorted ADI colors means color 1 = item rank 1, color 2 = item rank 2, and so on}
-#'   \item{\bold{workbook}}{the XlConnect Workbook for the Excel file to be changed\cr
-#' note: The workbook must be opened before}
-#'   \item{\bold{sheet}}{the sheet name ( ADI will be added to be sure not to delete any data}
-#'   \item{\bold{savecounts}}{if TRUE: save the counts of actions as sheet (availalbe only with workbook}
-#'   \item{\bold{saveAdi}}{if TRUE: save the FDI as sheet (availalbe only with workbook}
 #'  }  
 #' 
 #' 
@@ -34,13 +30,13 @@
 #' @return returns a list with\cr
 #'ADI - the Average Dominance index\cr
 #'Colors - the colors supported by vcolors sorted by ADI of the items\cr
-#'ADI_count_matrix - the counts from which the ADI was calulated\cr
+#'ADI_count_matrix - the counts from which the ADI was calculated\cr
 #' @author Knut Krueger, \email{Knut.Krueger@equine-science.de}
 #' @references {
 #' The Construction of Dominance Order: Comparing Performance of Five Methods Using an Individual-Based Model C. K. Hemelrijk, J. Wantia and L. Gygax, Behaviour Vol. 142, No. 8 (Aug., 2005), pp. 1037-1058
-#' \url{https://www.jstor.org/stable/4536286}\cr
+#' \doi{10.1163/156853905774405290}\cr
 #'On using the DomWorld model to evaluate dominance ranking methods , de Vries, Han,  Behaviour, Volume 146, Number 6, 2009 , pp. 843-869(27)
-#'\url{https://dx.doi.org/10.1163/156853909X412241}
+#'\doi{10.1163/156853909X412241}
 #' }
 #' 
 #' @examples { #you can eihter use:
@@ -64,9 +60,7 @@
 #' ADI(data_ADI,bytes)
 #' }
 #' @export ADI
-#' @importFrom gdata rename.vars  
-#' @importFrom XLConnect createSheet writeWorksheet saveWorkbook
-#' 
+
 
 ADI <- 
   function(data_sheet,bytes,...){
@@ -76,35 +70,6 @@ ADI <-
 #--------------------- parameter ----------
 args = list(...)
 
-if ("workbook" %in% names(args)){
-  wb <- args$workbook
-}
-
-
-if ("sheet" %in% names(args)) {
-  sheet_new <- paste(args$sheet, "ADI",sep="-")
-  sheet_new_counts <- paste(args$sheet, "counts",sep="-")
-}
-
-if ("savecounts" %in% names(args)){
-  savecounts <- args$savecounts
-  if ((savecounts != TRUE) && (savecounts != FALSE)){
-    warning("Error: savecounts must be TRUE or FALSE, default FALSE")
-    return ()
-  }  
-}
-else
-  savecounts<- "FALSE"
-
-if ("saveAdi" %in% names(args)){
-  savecounts <- args$saveAdi
-  if ((saveAdi != TRUE) && (savecounts != FALSE)){
-    warning("Error: saveAdi must be TRUE or FALSE, default FALSE")
-    return ()
-  }  
-}
-else
-  saveAdi<- "FALSE"
 
 if ("countmatrix" %in% names(args)){
   countmatrix <- args$countmatrix
@@ -251,9 +216,10 @@ for (X in (1:length(test[,1]-1)))
        vcolors2[X] <- vcolors[J]
       }
       }
-
-
-test2 <- rename.vars(test2, colnames(test2), c(rownames(test),colnames(test2[length(colnames(test2))-1]),colnames(test2[length(colnames(test2))])),info=FALSE)
+#if (!requireNamespace("gdata")){ 
+# stop("gdata not available")
+#}
+test2 <-rename.vars(test2, colnames(test2), c(rownames(test),colnames(test2[length(colnames(test2))-1]),colnames(test2[length(colnames(test2))])),info=FALSE)
 test2[,items+3]= test2[,items+3]= data.frame("rank"=position)
 
 result.data <- as.matrix(test2)
@@ -262,28 +228,6 @@ result.data <- as.matrix(test2)
 #     result.data <- result.data[order(result.data_sheet$results.ADI) , ] 
 #----------------------------------------------------------------------
 
-if ((exists("wb") )  && (exists("sheet_new"))) {
-  if (saveAdi==TRUE){
-  createSheet(wb, name = sheet_new)
-  writeWorksheet(wb,result.data,sheet=sheet_new,rownames="Row Names")
-  }
-  if(savecounts ==TRUE){
-    createSheet(wb, name = sheet_new_counts)
-    writeWorksheet(wb,tempdata[,1:items],sheet=sheet_new_counts,rownames="Row Names") 
-    
-  }
-  saveWorkbook(wb)
-  #delete warnings until Problem 
-  #1: In names(res)[1] <- colname :
-  #  number of items to replace is not a multiple of replacement length
-  # when adding rowmanes with writeWorksheet is solved
-  assign("last.warning", NULL, envir = baseenv())  
-  
-  
-}
-#else
-#  print('Remarks: No changes to excel sheet: missing wb or sheet')
-
    return(list("ADI"=result.data,"Colors"=vcolors2,"ADI_count_matrix"=tempdata[,1:items]))
 
 rm(test2)
